==> hoteldruid-mod-de_1.3.2-1.tar.gz: de/interconnessioni.php <==
<?php

switch ($messaggio) {

case "Aggiornamento eseguito con successo":  	$messaggio = "Aktualisierung erfolgreich"; break;
case "Non si è potuto portare a termine l'<div style=\"display: inline; color: red;\">aggiornamento</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Update</div> failed"; break;
case "OK":  					$messaggio = "OK"; break;
case "<div style=\"display: inline; color: red;\"><b>ATTENZIONE</b></div>: premendo su <b>\"<i>Continua</i>\"</b> tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":	$messaggio = "<div style=\"display: inline; color: red;\"><b>WARNING</b></div>: if you press <b>\"<i>Continue</i>\"</b> all data from <i>current database</i> will be <b>deleted</b>"; break;
case "Continua":  				$messaggio = "Weiter"; break;
case "Subordinazione creata":  			$messaggio = "Unterordnung erzeugt"; break;
case "Impossibile effettuare il collegamento, controllare i dati immessi":	$messaggio = "Verbindung abgebrochen, &uuml;berpr&uuml;fen Sie die eingegebenen Daten"; break;
case "Subordinazione cancellata":  		$messaggio = "Unterordnung gel&ouml;scht"; break;
case "Torna indietro":  			$messaggio = "Zur&uuml;ck"; break;
case "Interconnessioni con sorgenti esterne di dati":	$messaggio = "Interconnections with external data sources"; break;
case "Cancella":  				$messaggio = "L&ouml;schen"; break;
case "la subordinazione":  			$messaggio = "Unterordnung"; break;
case "Subordinazione ad un'altra installazione di hoteldruid":	$messaggio = "Subordination to another installation of hoteldruid"; break;
case "Con la subordinazione non si potranno inserire nuovi dati o apportare modifiche, ma solo importare i dati dall'installazione principale":	$messaggio = "Durch Unterordnung ist es nicht m&ouml;glich neue Daten ein zu geben oder &Auml;nderungen vorzunehmen, Sie k&ouml;nnen nur Daten von der Hauptinstallation importieren."; break;
case "Subordina questa installazione di hoteldruid a quella che si trova all'indirizzo":	$messaggio = "Subordinate this installation of hoteldruid to the one that is at"; break;
case "Password":  				$messaggio = "Passwort"; break;
case "Commento da aggiungere al titolo di questa installazione":	$messaggio = "Kommentar zum Titel dieser Installation hinzuf&uuml;gen"; break;
case "Crea la subordinazione":  		$messaggio = "Unterordnung erzeugen"; break;
case "Usa compressione":  			$messaggio = "Kompression einschalten"; break;
case "Utente per l'aggiornamento remoto delle interconnessioni":	$messaggio = "User to remotely update interconnections"; break;
case "Utente per l'aggiornamento remoto modificato":	$messaggio = "User for remote updates modified"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "Aggiornamento codice sorgente eseguito con successo":  	$messaggio = "Source code updated successfully"; break;
case "amministratore o utente con i privilegi per creare backup":	$messaggio = "administrator or user with privileges to create backups"; break;
case "nome utente":  				$messaggio = "username"; break;
case "Versione locale diversa da quella remota":	$messaggio = "Local version is different from the remote one"; break;
case "Non si è potuto scaricare il backup remoto":	$messaggio = "It was not possible to download the backup"; break;
case "Non si è potuto stabilire la connessione":	$messaggio = "It was not possible to establish the connection"; break;
case "Non ho i permassi di scrittura sulla cartella dati":	$messaggio = "I don't have write premissions on dati folder"; break;
case "Prova a mantenere i dati degli anni non presenti nell'installazione remota":	$messaggio = "Try to retain data of years not present in remote installation"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-de_2.1.2-1.tar.gz: de/interconnessioni.php <==
<?php

switch ($messaggio) {

case "Aggiornamento eseguito con successo":  	                            $messaggio = "Aktualisierung erfolgreich"; break;
case "Non si è potuto portare a termine l'<div style=\"display: inline; color: red;\">aggiornamento</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Update</div> fehlgeschlagen"; break;
case "OK":  					                            $messaggio = "OK"; break;
case "<div style=\"display: inline; color: red;\"><b>ATTENZIONE</b></div>: premendo su <b>\"<i>Continua</i>\"</b> tutti i dati del <i>database attuale</i> verranno <b>cancellati</b>":	                                            $messaggio = "<div style=\"display: inline; color: red;\"><b>WARNUNG</b></div>: Wenn Sie <b>\"<i>Weiter</i>\"</b> dr&uuml;cken, werden alle Daten der <i>aktuellen Datenbank</i><b>gel&ouml;scht</b>"; break;
case "Continua":  				                            $messaggio = "Weiter"; break;
case "Subordinazione creata":  			                            $messaggio = "Unterordnung erzeugt"; break;
case "Impossibile effettuare il collegamento, controllare i dati immessi":  $messaggio = "Verbindung abgebrochen, &uuml;berpr&uuml;fen Sie die eingegebenen Daten"; break;
case "Subordinazione cancellata":  		                            $messaggio = "Unterordnung gel&ouml;scht"; break;
case "Torna indietro":  			                            $messaggio = "Zur&uuml;ck"; break;
case "Cancella":  				                            $messaggio = "L&ouml;schen"; break;
case "la subordinazione":  			                            $messaggio = "Unterordnung"; break;
case "Con la subordinazione non si potranno inserire nuovi dati o apportare modifiche, ma solo importare i dati dall'installazione principale":	$messaggio = "Durch Unterordnung ist es nicht m&ouml;glich neue Daten ein zu geben oder &Auml;nderungen vorzunehmen, Sie k&ouml;nnen nur Daten von der Hauptinstallation importieren."; break;
case "Password":  				$messaggio = "Passwort"; break;
case "Commento da aggiungere al titolo di questa installazione":	$messaggio = "Kommentar zum Titel dieser Installation hinzuf&uuml;gen"; break;
case "Crea la subordinazione":  		$messaggio = "Unterordnung erzeugen"; break;
case "Usa compressione":  			$messaggio = "Kompression einschalten"; break;
case "Interconnessioni con sorgenti esterne di dati":	$messaggio = "Interconnections with external data sources"; break;
case "Subordinazione ad un'altra installazione di hoteldruid":	$messaggio = "Subordination to another installation of hoteldruid"; break;
case "Subordina questa installazione di hoteldruid a quella che si trova all'indirizzo":	$messaggio = "Subordinate this installation of hoteldruid to the one that is at"; break;
case "Utente per l'aggiornamento remoto delle interconnessioni":	$messaggio = "User to remotely update interconnections"; break;
case "Utente per l'aggiornamento remoto modificato":	$messaggio = "User for remote updates modified"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "Aggiornamento codice sorgente eseguito con successo":  	$messaggio = "Source code updated successfully"; break;
case "amministratore o utente con i privilegi per creare backup":	$messaggio = "administrator or user with privileges to create backups"; break;
case "nome utente":  				$messaggio = "username"; break;
case "Versione locale diversa da quella remota":	$messaggio = "Local version is different from the remote one"; break;
case "Non si è potuto scaricare il backup remoto":	$messaggio = "It was not possible to download the backup"; break;
case "Non si è potuto stabilire la connessione":	$messaggio = "It was not possible to establish the connection"; break;
case "Non ho i permassi di scrittura sulla cartella dati":	$messaggio = "I don't have write premissions on dati folder"; break;
case "Prova a mantenere i dati degli anni non presenti nell'installazione remota":	$messaggio = "Try to retain data of years not present in remote installation"; break;
case "nella pagina delle interconnessioni":  	$messaggio = "in interconnections page"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
